@@ -20,7 +20,7 @@ class ClientStreamUtils:
         consumer_group_instance_id: str = None,
         threshold_a: float = 0.95,
         threshold_b: float = 0.85,
-        enable_intelligent_transmission: bool = True,
+        enable_intelligent_transmission: bool = False,
     ):
         """Initialize ClientStreamUtils.
 
