@@ -443,8 +443,9 @@ class InferenceWorker:
                 self.cache_hits += 1
                 return "cached", cached_result
         
-        if action == "process" and await self._is_similar_to_cached_frame(message):
-            return "similar", None
+        # TODO: Enable this after testing and hanlding async and optimal threshold
+        # if action == "process" and await self._is_similar_to_cached_frame(message):
+        #     return "similar", None
         
         if await self._should_buffer_message(message):
             return "buffer", None
