@@ -106,6 +106,7 @@ class VehicleMonitoringUseCase(BaseProcessor):
         self._current_frame_track_ids = set()  # Store track IDs from current frame
         self._total_count = 0  # Cached total count
         self._last_update_time = time.time()  # Track when last updated
+        self._total_count_list = []
         
         # Zone-based tracking storage
         self._zone_current_track_ids = {}  # zone_name -> set of current track IDs in zone
@@ -293,7 +294,11 @@ class VehicleMonitoringUseCase(BaseProcessor):
                 # Check if detection center is inside the zone polygon using ray casting algorithm
                 if point_in_polygon(center_point, polygon_points):
                     current_frame_zone_tracks[zone_name].add(track_id)
-        
+                    if track_id not in self._total_count_list:
+                        self._total_count_list.append(track_id)
+        print("------------------------asd----------------------------------")
+        print(zone_analysis)
+        print("------------------------asd----------------------------------")
         # Update zone tracking for each zone
         for zone_name, zone_counts in zone_analysis.items():
             # Get current frame tracks for this zone
@@ -308,8 +313,11 @@ class VehicleMonitoringUseCase(BaseProcessor):
             # Update counts
             self._zone_current_counts[zone_name] = len(current_tracks)
             self._zone_total_counts[zone_name] = len(self._zone_total_track_ids[zone_name])
+            print("------------------------asd1----------------------------------")
             print(self._zone_current_counts)
+            print("------------------------asd1----------------------------------")
             print(self._zone_total_counts)
+            print("------------------------asd1----------------------------------")
             # Create enhanced zone analysis
             enhanced_zone_analysis[zone_name] = {
                 "current_count": self._zone_current_counts[zone_name],
@@ -606,7 +614,10 @@ class VehicleMonitoringUseCase(BaseProcessor):
                             "total_track_ids",
                             sum(v for v in counts_dict.values() if isinstance(v, (int, float)))
                         )
-                human_text_lines.append(f"\t{zone_name}: {int(total_count)}")
+            # zone_name = "Entrance"
+            # total_count = len(self._total_count_list)
+                if total_count>0:
+                    human_text_lines.append(f"\t{zone_name}: {int(total_count)}")
         else:
             for cat, count in total_counts_dict.items():
                 if count > 0:
